==> frostiful-2.2.6%2B1.21.1-sources.jar: com/github/thedeathlycow/frostiful/entity/GlacialArrowEntity.java <==
package com.github.thedeathlycow.frostiful.entity;

import com.github.thedeathlycow.frostiful.Frostiful;
import com.github.thedeathlycow.frostiful.registry.FEntityTypes;
import com.github.thedeathlycow.frostiful.registry.FItems;
import com.github.thedeathlycow.thermoo.api.temperature.HeatingModes;
import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_1665;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2398;
import net.minecraft.class_2487;
import net.minecraft.class_2520;
import org.jetbrains.annotations.Nullable;

public class GlacialArrowEntity extends class_1665 {

    private int freezeAmount = Frostiful.getConfig().icicleConfig.getFrostArrowFreezeAmount();

    private static final String FREEZE_AMOUNT_NBT_KEY = "freeze_amount";

    public GlacialArrowEntity(class_1299<? extends GlacialArrowEntity> entityType, class_1937 world) {
        super(entityType, world);
    }

    public GlacialArrowEntity(class_1937 world, double x, double y, double z, class_1799 stack, @Nullable class_1799 shotFrom) {
        super(FEntityTypes.GLACIAL_ARROW, x, y, z, world, stack, shotFrom);
    }

    public GlacialArrowEntity(class_1937 world, class_1309 owner, class_1799 stack, @Nullable class_1799 shotFrom) {
        super(FEntityTypes.GLACIAL_ARROW, owner, world, stack, shotFrom);
    }

    @Override
    public boolean method_5753() {
        return true;
    }

    @Override
    protected class_1799 method_57314() {
        return new class_1799(FItems.GLACIAL_ARROW);
    }

    @Override
    public void method_5773() {
        super.method_5773();

        class_1937 world = method_37908();
        if (world.field_9236 && !this.field_7588) {
            world.method_8406(
                    class_2398.field_28013,
                    this.method_23317(), this.method_23318(), this.method_23321(),
                    0.0D, 0.0D, 0.0D
            );
        }
    }

    @Override
    protected void method_7450(class_1309 target) {
        super.method_7450(target);
        target.thermoo$addTemperature(-freezeAmount, HeatingModes.ACTIVE);
    }

    @Override
    public void method_5749(class_2487 nbt) {
        super.method_5749(nbt);
        if (nbt.method_10573(FREEZE_AMOUNT_NBT_KEY, class_2520.field_33253)) {
            this.freezeAmount = nbt.method_10550(FREEZE_AMOUNT_NBT_KEY);
        }
    }

    @Override
    public void method_5652(class_2487 nbt) {
        super.method_5652(nbt);
        nbt.method_10569(FREEZE_AMOUNT_NBT_KEY, this.freezeAmount);
    }

}

==> frostiful-2.2.8%2B1.21.8-sources.jar: com/github/thedeathlycow/frostiful/entity/GlacialArrowEntity.java <==
package com.github.thedeathlycow.frostiful.entity;

import com.github.thedeathlycow.frostiful.Frostiful;
import com.github.thedeathlycow.frostiful.registry.FEntityTypes;
import com.github.thedeathlycow.frostiful.registry.FItems;
import com.github.thedeathlycow.thermoo.api.temperature.HeatingModes;
import net.minecraft.class_11368;
import net.minecraft.class_11372;
import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_1665;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2398;
import org.jetbrains.annotations.Nullable;

public class GlacialArrowEntity extends class_1665 {

    private int freezeAmount = Frostiful.getConfig().icicleConfig.getFrostArrowFreezeAmount();

    private static final String FREEZE_AMOUNT_NBT_KEY = "freeze_amount";

    public GlacialArrowEntity(class_1299<? extends GlacialArrowEntity> entityType, class_1937 world) {
        super(entityType, world);
    }

    public GlacialArrowEntity(class_1937 world, double x, double y, double z, class_1799 stack, @Nullable class_1799 shotFrom) {
        super(FEntityTypes.GLACIAL_ARROW, x, y, z, world, stack, shotFrom);
    }

    public GlacialArrowEntity(class_1937 world, class_1309 owner, class_1799 stack, @Nullable class_1799 shotFrom) {
        super(FEntityTypes.GLACIAL_ARROW, owner, world, stack, shotFrom);
    }

    @Override
    public boolean method_5753() {
        return true;
    }

    @Override
    protected class_1799 method_57314() {
        return new class_1799(FItems.GLACIAL_ARROW);
    }

    @Override
    public void method_5773() {
        super.method_5773();

        class_1937 world = method_37908();
        if (world.field_9236 && !this.method_65059()) {
            world.method_8406(
                    class_2398.field_28013,
                    this.method_23317(), this.method_23318(), this.method_23321(),
                    0.0D, 0.0D, 0.0D
            );
        }
    }

    @Override
    protected void method_7450(class_1309 target) {
        super.method_7450(target);
        target.thermoo$addTemperature(-freezeAmount, HeatingModes.ACTIVE);
    }

    @Override
    public void method_5749(class_11368 readView) {
        super.method_5749(readView);
        this.freezeAmount = readView.method_71424(FREEZE_AMOUNT_NBT_KEY, 0);
    }

    @Override
    public void method_5652(class_11372 writeView) {
        super.method_5652(writeView);
        writeView.method_71465(FREEZE_AMOUNT_NBT_KEY, this.freezeAmount);
    }

}
